import requests


class EngineApi(object):
    """
    General API interface to engine application
    """

    def __init__(self, host="http://localhost:8000", token=None):
        self.base_url = host + '/engine/api'
        self.headers = {'Authorization': 'Token {}'.format(token)} if token else {}
        self.client = self.get_client()
        self.client.headers.update(self.headers)

    def get_client(self):
        return requests.Session()

    def create_activity(self, **kwargs):
        return self.client.post(
            self.base_url + '/activity',
            json=kwargs
        )

    def recommend(self, learner=None, collection=None, sequence=None):
        return self.client.post(
            self.base_url + '/activity/recommend',
            json=dict(learner=learner, collection=collection, sequence=sequence)
        )

    def submit_score(self, learner=None, activity=None, score=None):
        return self.client.post(
            self.base_url + '/score',
            json=dict(learner=learner, activity=activity, score=score)
        )

    def bulk_update_mastery(self, data):
        return self.client.put(
            self.base_url + '/mastery/bulk_update',
            json=data
        )

    def create_knowledge_component(self, **kwargs):
        return self.client.post(
            self.base_url + '/knowledge_component',
            json=kwargs
        )



import requests


class BridgeApi(object):
    """
    General API interface to bridge application
    """

    def __init__(self, host="http://localhost:8008", token=None):
        self.base_url = host + '/api'
        self.headers = {'Authorization': 'Token {}'.format(token)} if token else {}
        self.client = self.get_client()
        self.client.headers.update(self.headers)

    def get_client(self):
        return requests.Session()

    def get_collection(self, **kwargs):
        return self.client.get(
            self.base_url + '/collection',
            json=kwargs
        )

    def create_collection(self, **kwargs):
        """
        Collection fields:
            name
            metadata
            strict_forward
            owner
        """
        return self.client.post(
            self.base_url + '/collection/',
            json=kwargs
        )

    def delete_collection(self, **kwargs):
        return self.client.delete(
            self.base_url + '/collection/',
            json=kwargs
        )

    def get_activity(self, **kwargs):
        return self.client.get(
            self.base_url + '/activity/',
            json=kwargs
        )

    def create_activity(self, **kwargs):
        return self.client.post(
            self.base_url + '/activity/',
            json=kwargs
        )

    def delete_activity(self, **kwargs):
        return self.client.delete(
            self.base_url + '/activity/',
            json=kwargs
        )



from setuptools import setup

setup(
    name='alosi',
    version='0.0.3',
    description='Utilities for the ALOSI adaptive learning system',
    url='https://github.com/harvard-vpal/alosi',
    author='Andrew Ang',
    author_email='andrew_ang@harvard.edu',
    license='Apache-2.0',
    packages=['alosi'],
    install_requires=[
        'requests==2.18.4',
        'numpy==1.14.0',
        'pandas==0.22.0',
        'google-auth==1.5.0',
        'google-auth-oauthlib==0.2.0',
        'gspread==3.0.0'
    ]
)
